@@ -1,11 +1,20 @@
 import argparse as ap
 from os.path import basename, splitext
+import logging
+import logging.config
 
 from pymongo import MongoClient
 from prettytable import PrettyTable
 
 from srsparser import SRSParser
 from srsparser.nlp import NLProcessor
+from srsparser import configs
+
+
+def init_logger() -> logging.Logger:
+    logging.config.dictConfig(configs.LOGGING_CONFIG)
+    logger = logging.getLogger('my_logger')
+    return logger
 
 
 def init_args_parser() -> ap.ArgumentParser:
@@ -85,57 +94,75 @@ def init_args_parser() -> ap.ArgumentParser:
 def main():
     parser = init_args_parser()
     args = parser.parse_args()
+    logger = init_logger()
 
     client = MongoClient(args.mongodb_url)
     db = client.get_default_database()
+    logger.info('the connection to the database ("%s") is established', db.name)
 
     results_coll = db[args.results_coll]
+    logger.info('the connection to the results collection ("%s") is established', results_coll.name)
+
     if args.results:
-        print(f'documents in MongoDB results collection ({args.results_coll}):')
-        docx_structures = results_coll.find({})
-        for structure in docx_structures:
-            print(f'"{structure["document_name"]}"', end=' ')
-            return
+        logger.info('documents in results collection ("%s"):', args.results_coll)
+        logger.info('%s', [structure['document_name'] for structure in results_coll.find({})])
 
     mode = args.mode.lower()
+    logger.info('operating mode: %s', mode)
+
     if mode == 'parse':
         tmpl_coll = db[args.tmpl_coll]
-        tree_template = tmpl_coll.find_one({'name': args.tmpl})['structure']
+        logger.info('the connection to the templates collection ("%s") is established', tmpl_coll.name)
 
-        parser = SRSParser(tree_template)
+        structure_template = tmpl_coll.find_one({'name': args.tmpl})['structure']
+        logger.info('a structure template was obtained from the collection with the results: %s', structure_template)
+
+        parser = SRSParser(structure_template)
         document_structure = parser.parse_docx(args.docx_path)
+        logger.info('based on the content of the document ("%s"), a section structure was created: %s', args.docx_path,
+                    document_structure)
 
         document_name = splitext(basename(args.docx_path))[0]
 
         results_coll.insert_one({'document_name': document_name, 'structure': document_structure})
-        print('successful! check the results collection')
+        logger.info('successful! the created section structure is loaded into the results collection ("%s")',
+                    results_coll.name)
     elif mode == 'keywords':
-        docx_structures = list(results_coll.find({}))
+        results = list(results_coll.find({}))
 
         docx_structure_idx = -1
-        for idx in range(len(docx_structures)):
-            if docx_structures[idx]['document_name'] == args.docx_name:
+        for idx in range(len(results)):
+            if results[idx]['document_name'] == args.docx_name:
                 docx_structure_idx = idx
+                logger.info('the document "%s" was found in the results collection under the sequence number %s!',
+                            args.docx_name, docx_structure_idx + 1)
                 break
         if docx_structure_idx < 0:
-            print(f'there is no such document in the database with name "{args.docx_name}"')
+            logger.error('there is no such document in the results collection with document name "%s"', args.docx_name)
             return
 
+        logger.info('initializing SDK pullenti...')
         nlp = NLProcessor(init_pullenti=True)
+        logger.info('OK!')
 
-        tf_idf_keywords = nlp.get_keywords_tf_idf(docx_structures, docx_structure_idx)
-        print('tf-idf keywords:', tf_idf_keywords)
+        tf_idf_keywords = nlp.get_keywords_tf_idf(
+            structures=[result['structure'] for result in results],
+            structure_idx=docx_structure_idx
+        )
+        logger.info('keywords are obtained using the TF-IDF model')
 
-        docx_structure = docx_structures[docx_structure_idx]['structure']
-        pullenti_keywords = nlp.get_keywords_pullenti(docx_structure)
+        pullenti_keywords = nlp.get_keywords_pullenti(
+            structure=results[docx_structure_idx]['structure']
+        )
+        logger.info('keywords are obtained using the pullenti package')
 
-        mytable = PrettyTable()
-        mytable.add_column('TD-IDF', tf_idf_keywords[:10])
-        mytable.add_column('Pullenti', pullenti_keywords[:10])
+        keywords_table = PrettyTable()
+        keywords_table.add_column('TD-IDF', tf_idf_keywords[:10])
+        keywords_table.add_column('Pullenti', pullenti_keywords[:10])
 
-        print(mytable)
+        logger.info('below are the top 10 keywords:\n%s', keywords_table)
     else:
-        print('the mode does not exist!')
+        logger.error('the mode "%s" does not exist!', mode)
 
     client.close()
 
