@@ -21,9 +21,7 @@ class NLProcessor:
         self.morph = MorphAnalyzer()
 
         if init_pullenti:
-            print(f'Initializing SDK Pullenti ver {Sdk.get_version()} ({Sdk.get_version_date()})...')
             Sdk.initialize_all()
-            print(f'OK! version {ProcessorService.get_version()}')
 
     @staticmethod
     def remove_stop_words(words: List[str]) -> List[str]:
@@ -173,7 +171,6 @@ class NLProcessor:
                             section_name='Техническое задание',
                             part_of_speech='') -> List[str]:
         tf_idf_weights = self.get_structures_tf_idf_weights(structures, section_name, part_of_speech)
-        print('tf_idf weights:', tf_idf_weights)
         return [tf_idf_weight[0] for tf_idf_weight in tf_idf_weights[structure_idx]]
 
     def get_keywords_pullenti(self, structure: dict, section_name='Техническое задание') -> List[str]:
